@@ -1,6 +1,6 @@
 /*
  * tst_usersfile.c - self-tests for Liboath usersfile functions
- * Copyright (C) 2009-2012 Simon Josefsson
+ * Copyright (C) 2009-2013 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -353,6 +353,25 @@ main (void)
       return 1;
     }
 
+  /* Test password field of + */
+  rc = oath_authenticate_usersfile (CREDS,
+				    "plus", "328482", 1, "4711", &last_otp);
+  if (rc != OATH_OK)
+    {
+      printf ("oath_authenticate_usersfile[26]: %s (%d)\n",
+	      oath_strerror_name (rc), rc);
+      return 1;
+    }
+
+  rc = oath_authenticate_usersfile (CREDS,
+				    "plus", "812658", 1, "4712", &last_otp);
+  if (rc != OATH_OK)
+    {
+      printf ("oath_authenticate_usersfile[27]: %s (%d)\n",
+	      oath_strerror_name (rc), rc);
+      return 1;
+    }
+
   rc = oath_done ();
   if (rc != OATH_OK)
     {
