@@ -1,6 +1,6 @@
 /*
  * usersfile.c - implementation of UsersFile based HOTP validation
- * Copyright (C) 2009-2012 Simon Josefsson
+ * Copyright (C) 2009-2013 Simon Josefsson
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -121,6 +121,10 @@ parse_usersfile (const char *username,
 	      if (*passwd != '\0')
 		return OATH_BAD_PASSWORD;
 	    }
+	  else if (strcmp (p, "+") == 0)
+	    {
+	      /* Externally verified. */
+	    }
 	  else if (strcmp (p, passwd) != 0)
 	    return OATH_BAD_PASSWORD;
 	}
